==> open-cluster-management-agent-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/OpenClusterManagementAgentSchemaBuilder.java <==
package io.fabric8.openclustermanagement.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OpenClusterManagementAgentSchemaBuilder extends OpenClusterManagementAgentSchemaFluent<OpenClusterManagementAgentSchemaBuilder> implements VisitableBuilder<OpenClusterManagementAgentSchema,OpenClusterManagementAgentSchemaBuilder>{
  public OpenClusterManagementAgentSchemaBuilder() {
    this(false);
  }
  public OpenClusterManagementAgentSchemaBuilder(Boolean validationEnabled) {
    this(new OpenClusterManagementAgentSchema(), validationEnabled);
  }
  public OpenClusterManagementAgentSchemaBuilder(OpenClusterManagementAgentSchemaFluent<?> fluent) {
    this(fluent, false);
  }
  public OpenClusterManagementAgentSchemaBuilder(OpenClusterManagementAgentSchemaFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OpenClusterManagementAgentSchema(), validationEnabled);
  }
  public OpenClusterManagementAgentSchemaBuilder(OpenClusterManagementAgentSchemaFluent<?> fluent,OpenClusterManagementAgentSchema instance) {
    this(fluent, instance, false);
  }
  public OpenClusterManagementAgentSchemaBuilder(OpenClusterManagementAgentSchemaFluent<?> fluent,OpenClusterManagementAgentSchema instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new OpenClusterManagementAgentSchema());

    if (instance != null) {
      fluent.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonAgentConfigSpec(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonAgentConfigSpec());
      fluent.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfig(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfig());
      fluent.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigList(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigList());
      fluent.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigSpec(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigSpec());
      fluent.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigStatus(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigStatus());
      fluent.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1ProxyConfig(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1ProxyConfig());
      fluent.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonAgentConfigSpec(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonAgentConfigSpec());
      fluent.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfig(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfig());
      fluent.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigList(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigList());
      fluent.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigSpec(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigSpec());
      fluent.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigStatus(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigStatus());
      fluent.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1ProxyConfig(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1ProxyConfig());
    }
    this.validationEnabled = validationEnabled; 
  }
  public OpenClusterManagementAgentSchemaBuilder(OpenClusterManagementAgentSchema instance) {
    this(instance,false);
  }
  public OpenClusterManagementAgentSchemaBuilder(OpenClusterManagementAgentSchema instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new OpenClusterManagementAgentSchema());

    if (instance != null) {
      this.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonAgentConfigSpec(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonAgentConfigSpec());
      this.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfig(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfig());
      this.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigList(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigList());
      this.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigSpec(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigSpec());
      this.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigStatus(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigStatus());
      this.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1ProxyConfig(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1ProxyConfig());
      this.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonAgentConfigSpec(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonAgentConfigSpec());
      this.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfig(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfig());
      this.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigList(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigList());
      this.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigSpec(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigSpec());
      this.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigStatus(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigStatus());
      this.withGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1ProxyConfig(instance.getGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1ProxyConfig());
    }
    this.validationEnabled = validationEnabled; 
  }
  OpenClusterManagementAgentSchemaFluent<?> fluent;
  Boolean validationEnabled;
  public OpenClusterManagementAgentSchema build() {
    OpenClusterManagementAgentSchema buildable = new OpenClusterManagementAgentSchema(fluent.buildGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonAgentConfigSpec(),fluent.buildGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfig(),fluent.buildGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigList(),fluent.buildGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigSpec(),fluent.buildGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigStatus(),fluent.buildGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1ProxyConfig());
    return buildable;
  }
  
}

==> open-cluster-management-agent-model-6.10.0-sources.jar: io/fabric8/openclustermanagement/api/model/OpenClusterManagementAgentSchemaBuilder.java <==
package io.fabric8.openclustermanagement.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
public class OpenClusterManagementAgentSchemaBuilder extends OpenClusterManagementAgentSchemaFluent<OpenClusterManagementAgentSchemaBuilder> implements VisitableBuilder<OpenClusterManagementAgentSchema,OpenClusterManagementAgentSchemaBuilder>{
  public OpenClusterManagementAgentSchemaBuilder() {
    this(new OpenClusterManagementAgentSchema());
  }
  
  public OpenClusterManagementAgentSchemaBuilder(OpenClusterManagementAgentSchemaFluent<?> fluent) {
    this(fluent, new OpenClusterManagementAgentSchema());
  }
  
  public OpenClusterManagementAgentSchemaBuilder(OpenClusterManagementAgentSchemaFluent<?> fluent,OpenClusterManagementAgentSchema instance) {
    this.fluent = fluent;
    fluent.copyInstance(instance);
  }
  
  public OpenClusterManagementAgentSchemaBuilder(OpenClusterManagementAgentSchema instance) {
    this.fluent = this;
    this.copyInstance(instance);
  }
  OpenClusterManagementAgentSchemaFluent<?> fluent;
  
  public OpenClusterManagementAgentSchema build() {
    OpenClusterManagementAgentSchema buildable = new OpenClusterManagementAgentSchema(fluent.buildGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonAgentConfigSpec(),fluent.buildGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfig(),fluent.buildGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigList(),fluent.buildGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigSpec(),fluent.buildGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1KlusterletAddonConfigStatus(),fluent.buildGithubComOpenClusterManagementKlusterletAddonControllerPkgApisAgentV1ProxyConfig());
    return buildable;
  }
  

}
